@@ -11,7 +11,7 @@ InsertAssignments = Union[
 LimitOffset = Tuple[Optional[int], Optional[int]]
 
 Record = Mapping[str, Any]
-
-RecordsAndCount = Tuple[List[Record], int]
+Records = List[Record]
+RecordsAndCount = Tuple[Records, int]
 
 SQL = Tuple[Optional[str], List[Any]]
